==> aws-cdk.aws-resiliencehub-1.138.1.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_resiliencehub_CfnResiliencyPolicyProps(p) {
}
function _aws_cdk_aws_resiliencehub_CfnAppProps(p) {
}
function _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy(p) {
}
function _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy_FailurePolicyProperty(p) {
}
function _aws_cdk_aws_resiliencehub_CfnApp(p) {
}
function _aws_cdk_aws_resiliencehub_CfnApp_PhysicalResourceIdProperty(p) {
}
function _aws_cdk_aws_resiliencehub_CfnApp_ResourceMappingProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicyProps, _aws_cdk_aws_resiliencehub_CfnAppProps, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy_FailurePolicyProperty, _aws_cdk_aws_resiliencehub_CfnApp, _aws_cdk_aws_resiliencehub_CfnApp_PhysicalResourceIdProperty, _aws_cdk_aws_resiliencehub_CfnApp_ResourceMappingProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-resiliencehub-1.140.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_resiliencehub_CfnAppProps(p) {
}
function _aws_cdk_aws_resiliencehub_CfnResiliencyPolicyProps(p) {
}
function _aws_cdk_aws_resiliencehub_CfnApp(p) {
}
function _aws_cdk_aws_resiliencehub_CfnApp_PhysicalResourceIdProperty(p) {
}
function _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy(p) {
}
function _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy_FailurePolicyProperty(p) {
}
function _aws_cdk_aws_resiliencehub_CfnApp_ResourceMappingProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_resiliencehub_CfnAppProps, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicyProps, _aws_cdk_aws_resiliencehub_CfnApp, _aws_cdk_aws_resiliencehub_CfnApp_PhysicalResourceIdProperty, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy, _aws_cdk_aws_resiliencehub_CfnResiliencyPolicy_FailurePolicyProperty, _aws_cdk_aws_resiliencehub_CfnApp_ResourceMappingProperty };
module.exports.DeprecationError = DeprecationError;
